##  Prerequisites
Before you start, refer to additional information:
  * Learn about the SSO configuration process in [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD).
  * Refer to the [Microsoft Entra ID documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fentra%2Fidentity%2F "https://learn.microsoft.com/en-us/entra/identity/").
